@@ -6,7 +6,7 @@ test_that("calculation of raw summaries work", {
 
     # load example data
     file <- paste0("https://raw.githubusercontent.com/rqtl/",
-                   "qtl2data/master/DOex/DOex.zip")
+                   "qtl2data/main/DOex/DOex.zip")
     DOex <- read_cross2(file)
     indIDs <- ind_ids(DOex)
     mnames <- marker_names(DOex)
