@@ -18,4 +18,9 @@ test_that("plot_genes works", {
 
     expect_doppelganger("plot_genes", test_plot_genes)
 
+    # try again with the genes in a different order
+    genes <- genes[c(8,5,4,6,2,3,7,1),]
+
+    expect_doppelganger("plot_genes", test_plot_genes)
+
 })
